/**
 * JBoss, Home of Professional Open Source
 * Copyright 2017, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */ 
package com.redhat.cee.sce.lodh.case01814998.test.web;

import static org.junit.Assert.*;

import java.net.URL;

import javax.ws.rs.ApplicationPath;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.resteasy.client.ProxyFactory;
import org.jboss.resteasy.plugins.providers.RegisterBuiltin;
import org.jboss.resteasy.spi.ResteasyProviderFactory;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.redhat.cee.sce.lodh.case01814998.web.IEchoRest;
import com.redhat.cee.sce.lodh.case01814998.web.rs.JaxRsActivator;

/**
 *
 * @author <a href="mailto:clichybi@redhat.com">Carsten Lichy-Bittendorf</a>
 * @version $Revision$
 * $Date$:    Date of last commit
 *
 */
@RunWith(Arquillian.class)
@RunAsClient
public class SimpleEchoTest {
	
	private static final String RESOURCE_PREFIX = JaxRsActivator.class.getAnnotation(ApplicationPath.class).value().substring(1);
	
	@Deployment
	public static WebArchive createWebDeployment() {
		
		WebArchive war = ShrinkWrap.create(WebArchive.class, "lodh-case01814998-web.war")
        		.addPackage(IEchoRest.class.getPackage())
        		.addPackage(JaxRsActivator.class.getPackage())
				.addAsManifestResource(EmptyAsset.INSTANCE, "WEB-INF/beans.xml")
				.setWebXML("WEB-INF/web.xml");
		
		return war;
		
	}
	
	@ArquillianResource
	URL deploymentUrl;

	@BeforeClass
	public static void initResteasyClient() {
		RegisterBuiltin.register(ResteasyProviderFactory.getInstance());
	}

	@Test
	public void simpleEchoTest() throws Exception {
		String message2echo = "some statement";
		System.out.println("URL: "+deploymentUrl.toString() + RESOURCE_PREFIX);
		IEchoRest client = ProxyFactory.create(IEchoRest.class, deploymentUrl.toString() + RESOURCE_PREFIX);
		
		String echo = client.echo(message2echo);
		
		assertNotNull(echo);
		assertEquals(message2echo, echo);
		
	}

}
